/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Fabien Vultier
 *   Co-authors:
 *      ...
 *
 */

/**
    @file SOBGumba.cc
    @brief All items in this minigame inherit from this class. Items can move around like platforms and enemies.
*/

#include "SOBGumba.h"

#include "core/CoreIncludes.h"
#include "core/XMLPort.h"
#include "SOBFigure.h"
#include "util/Output.h"


namespace orxonox
{
    RegisterClass(SOBGumba);

    SOBGumba::SOBGumba(Context* context) : MovableEntity(context)
    {
        RegisterObject(SOBGumba);

        attachedToFigure_ = false;
        setAngularFactor(0.0);
        figure_ = nullptr;
        this->enableCollisionCallback();
        gravityAcceleration_ = 350.0;
        speed_ = 0.0;
        hasCollided_=false;
        goesRight_ = true;
        lastPos_ = getPosition();
        lastPos_.x -= 20;
        changeAllowed_ = true;
        changedOn_ = 0.0;
        
    }

    

    void SOBGumba::XMLPort(Element& xmlelement, XMLPort::Mode mode)
    {
        SUPER(SOBGumba, XMLPort, xmlelement, mode);
        XMLPortParam(SOBGumba, "speed", setSpeed, getSpeed, xmlelement, mode);


    }

    
    bool SOBGumba::collidesAgainst(WorldEntity* otherObject, const btCollisionShape* ownCollisionShape, btManifoldPoint& contactPoint) {


        if (changeAllowed_ && otherObject->getMass() != -1) {
            goesRight_ = !goesRight_;
            changeAllowed_ = false;
        }

        return true;
    }


    void SOBGumba::setFigure(SOBFigure* newFigure)
    {
        figure_ = newFigure;
    }

    void SOBGumba::touchFigure()
    {

    }

    void SOBGumba::tick(float dt)
    {
        SUPER(SOBGumba, tick, dt);

        if (!changeAllowed_) {
            changedOn_+= dt;
            if (changedOn_> 200) {
                changeAllowed_ = true;
                changedOn_ = 0.0;

            }
        }
        

        int dir = 1;
        if (!goesRight_)
            dir = -1;

        Vector3 velocity = getVelocity();
        velocity.z -= gravityAcceleration_*dt;
        velocity.x = dir*speed_;
        setVelocity(velocity);


        
        lastPos_ = getPosition();
    }


}
/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Fabien Vultier
 *   Co-authors:
 *      ...
 *
 */

/**
    @file SOBGumba.h
    @brief Declaration of the SOBGumba class.
    @ingroup SOB
*/

#ifndef _SOBGumba_H__
#define _SOBGumba_H__

#include "superorxobros/SOBPrereqs.h"
#include "worldentities/MovableEntity.h"


namespace orxonox
{
    class _SOBExport SOBGumba : public MovableEntity
    {
    public:
        SOBGumba(Context* context);
        virtual void XMLPort(Element& xmlelement, XMLPort::Mode mode) override;
        virtual void setFigure(SOBFigure* newFigure);
        virtual void touchFigure();
        virtual  bool collidesAgainst(WorldEntity* otherObject, const btCollisionShape* ownCollisionShape, btManifoldPoint& contactPoint) override;
        virtual void tick(float dt) override;

        
        bool attachedToFigure_;

        void setSpeed(const float speed)
        { this->speed_ = speed; }
        float getSpeed() const
        { return speed_; }

        bool hasCollided_;
    protected:
        float gravityAcceleration_;
        float speed_;
        WeakPtr<SOBFigure> figure_;
        bool goesRight_;
        Vector3 lastPos_;
        bool changeAllowed_;
        float changedOn_;
        
    };
}

#endif /* _SOBGumba_H__ */
